"""Top-level package for Generic API wrapper."""

__author__ = """Sergii Gryshkevych"""
__email__ = ""
__version__ = "0.2.0"


from generic_api_wrapper.aws_iam_auth import AwsIamAuth
from generic_api_wrapper.generic_api_wrapper import Api
